@@ -37,42 +37,42 @@
 #include <stdlib.h>
 #include <string.h>
 
-static void wordlist_view_class_init(WordlistViewClass *klass);
-static void wordlist_view_init(WordlistView *view);
-static void wordlist_view_finalize(GObject *object);
-static void wordlist_view_destroy(GtkObject *object);
+static void wordlist_view_class_init   (WordlistViewClass *klass);
+static void wordlist_view_init         (WordlistView *view);
+static void wordlist_view_finalize     (GObject *object);
+static void wordlist_view_destroy      (GtkObject *object);
 
-static void wordlist_view_set_property(GObject *object,
-				       guint prop_id,
-				       const GValue *value,
-				       GParamSpec *pspec);
-static void wordlist_view_get_property(GObject *object,
-				       guint prop_id,
-				       GValue *value,
-				       GParamSpec *pspec);
+static void wordlist_view_set_property (GObject *object,
+					guint prop_id,
+					const GValue *value,
+					GParamSpec *pspec);
+static void wordlist_view_get_property (GObject *object,
+					guint prop_id,
+					GValue *value,
+					GParamSpec *pspec);
 
 /* callbacks */
-static void wordlist_view_callback_cell_edited(GtkCellRendererText *renderer,
-					       const gchar *path_string,
-					       const gchar *new_text,
-					       WordlistView *view);
+static void wordlist_view_callback_cell_edited (GtkCellRendererText *renderer,
+						const gchar *path_string,
+						const gchar *new_text,
+						WordlistView *view);
 
 static GtkScrolledWindowClass *parent_class = NULL;
 
 enum {
     PROP_0,
-    PROP_CODE_SHOW,
-    PROP_HINSHI_SHOW,
+    PROP_CCLASS_CODE_SHOW,
     PROP_FREQ_SHOW,
+    PROP_OKURI_SHOW,
     PROP_EDITABLE,
     PROP_SELECTION_MODE,
 };
 
 typedef enum {
-    WORDLIST_YOMI = 0,
-    WORDLIST_KANJI,
-    WORDLIST_CODE,
-    WORDLIST_HINSHI,
+    WORDLIST_WORD_TYPE = 0,
+    WORDLIST_PHON,
+    WORDLIST_DESC,
+    WORDLIST_CCLASS_CODE,
     WORDLIST_FREQ,
     WORDLIST_OKURI,
     WORDLIST_EDITABLE,
@@ -101,7 +101,7 @@ GType wordlist_view_get_type(void) {
 }
 
 static void wordlist_view_class_init(WordlistViewClass *klass) {
-    GObjectClass *gobject_class = G_OBJECT_CLASS(klass);
+    GObjectClass   *gobject_class = G_OBJECT_CLASS(klass);
     GtkObjectClass *object_class = GTK_OBJECT_CLASS(klass);
 
     parent_class = g_type_class_peek_parent(klass);
@@ -112,19 +112,13 @@ static void wordlist_view_class_init(WordlistViewClass *klass) {
     object_class->destroy = wordlist_view_destroy;
 
     g_object_class_install_property(gobject_class,
-				    PROP_CODE_SHOW,
-				    g_param_spec_boolean("code_show",
-							 _("Show code column"),
+				    PROP_CCLASS_CODE_SHOW,
+				    g_param_spec_boolean("cclass_code_show",
+							 _("Show conjection class code column"),
 							 _(""),
 							 FALSE,
 							 G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
-    g_object_class_install_property(gobject_class,
-				    PROP_HINSHI_SHOW,
-				    g_param_spec_boolean("hinshi_show",
-							 _("Show hinshi column"),
-							 _(""),
-							 TRUE,
-							 G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+
     g_object_class_install_property(gobject_class,
 				    PROP_FREQ_SHOW,
 				    g_param_spec_boolean("freq_show",
@@ -132,6 +126,13 @@ static void wordlist_view_class_init(WordlistViewClass *klass) {
 							 _(""),
 							 FALSE,
 							 G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
+    g_object_class_install_property(gobject_class,
+				    PROP_OKURI_SHOW,
+				    g_param_spec_boolean("okuri_show",
+							 _("Show okuri column"),
+							 _(""),
+							 FALSE,
+							 G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
     g_object_class_install_property(gobject_class,
 				    PROP_EDITABLE,
 				    g_param_spec_boolean("editable",
@@ -172,65 +173,65 @@ static void wordlist_view_init(WordlistView *view) {
     view->selection = gtk_tree_view_get_selection(view->view);
     gtk_tree_selection_set_mode(view->selection, GTK_SELECTION_SINGLE);
 
-    /* Yomi */
+
+    /* Word Type */
+    renderer = gtk_cell_renderer_text_new();
+    g_object_set_data(G_OBJECT(renderer), "column",
+		      GINT_TO_POINTER(WORDLIST_WORD_TYPE));
+    column = gtk_tree_view_column_new_with_attributes(_("Word Type"), renderer,
+						      "text", WORDLIST_WORD_TYPE,						      "editable", WORDLIST_EDITABLE,
+						      NULL);
+
+    gtk_tree_view_column_set_visible(column, TRUE);
+    gtk_tree_view_append_column(view->view, column);
+    view->word_type_column = column;
+
+    /* Phon */
     renderer = gtk_cell_renderer_text_new();
     g_signal_connect(renderer, "edited",
 		     G_CALLBACK(wordlist_view_callback_cell_edited),
 		     view);
     g_object_set_data(G_OBJECT(renderer), "column",
-		      GINT_TO_POINTER(WORDLIST_YOMI));
-    column = gtk_tree_view_column_new_with_attributes(_("Yomi"), renderer,
-						      "text", WORDLIST_YOMI,
+		      GINT_TO_POINTER(WORDLIST_PHON));
+    column = gtk_tree_view_column_new_with_attributes(_("Phon"), renderer,
+						      "text", WORDLIST_PHON,
 						      "editable", WORDLIST_EDITABLE,
 						      NULL);
     gtk_tree_view_column_set_visible(column, TRUE);
     gtk_tree_view_append_column(view->view, column);
-    view->yomi_column = column;
+    view->phon_column = column;
 
-    /* Kanji */
+    /* Desc */
     renderer = gtk_cell_renderer_text_new();
     g_signal_connect(renderer, "edited",
 		     G_CALLBACK(wordlist_view_callback_cell_edited),
 		     view);
     g_object_set_data(G_OBJECT(renderer), "column",
-		      GINT_TO_POINTER(WORDLIST_KANJI));
-    column = gtk_tree_view_column_new_with_attributes(_("Kanji"), renderer,
-						      "text", WORDLIST_KANJI,
+		      GINT_TO_POINTER(WORDLIST_DESC));
+    column = gtk_tree_view_column_new_with_attributes(_("Description"),
+						      renderer,
+						      "text", WORDLIST_DESC,
 						      "editable", WORDLIST_EDITABLE,
 						      NULL);
     gtk_tree_view_append_column(view->view, column);
     gtk_tree_view_column_set_visible(column, TRUE);
-    view->kanji_column = column;
+    view->desc_column = column;
 
-    /* Code */
+    /* Conjection Class Code */
     renderer = gtk_cell_renderer_text_new();
     g_signal_connect(renderer, "edited",
 		     G_CALLBACK(wordlist_view_callback_cell_edited),
 		     view);
     g_object_set_data(G_OBJECT(renderer), "column",
-		      GINT_TO_POINTER(WORDLIST_CODE));
-    column = gtk_tree_view_column_new_with_attributes(_("Code"), renderer,
-						      "text", WORDLIST_CODE,
+		      GINT_TO_POINTER(WORDLIST_CCLASS_CODE));
+    column = gtk_tree_view_column_new_with_attributes(_("Conjection Class Code"),
+						      renderer,
+						      "text", WORDLIST_CCLASS_CODE,
 						      "editable", WORDLIST_EDITABLE,
 						      NULL);
     gtk_tree_view_column_set_visible(column, FALSE);
     gtk_tree_view_append_column(view->view, column);
-    view->code_column = column;
-
-    /* Hinshi */
-    renderer = gtk_cell_renderer_text_new();
-    g_signal_connect(renderer, "edited",
-		     G_CALLBACK(wordlist_view_callback_cell_edited),
-		     view);
-    g_object_set_data(G_OBJECT(renderer), "column",
-		      GINT_TO_POINTER(WORDLIST_HINSHI));
-    column = gtk_tree_view_column_new_with_attributes(_("Hinshi"), renderer,
-						      "text", WORDLIST_HINSHI,
-						      "editable", WORDLIST_EDITABLE,
-						      NULL);
-    gtk_tree_view_column_set_visible(column, TRUE);
-    gtk_tree_view_append_column(view->view, column);
-    view->hinshi_column = column;
+    view->cclass_code_column = column;
 
     /* Freq */
     renderer = gtk_cell_renderer_text_new();
@@ -239,7 +240,7 @@ static void wordlist_view_init(WordlistView *view) {
 		     view);
     g_object_set_data(G_OBJECT(renderer), "column",
 		      GINT_TO_POINTER(WORDLIST_FREQ));
-    column = gtk_tree_view_column_new_with_attributes(_("Freq"), renderer,
+    column = gtk_tree_view_column_new_with_attributes(_("Frequency"), renderer,
 						      "text", WORDLIST_FREQ,
 						      "editable", WORDLIST_EDITABLE,
 						      NULL);
@@ -249,29 +250,29 @@ static void wordlist_view_init(WordlistView *view) {
 
     /* Okuri */
     renderer = gtk_cell_renderer_text_new();
-    column = gtk_tree_view_column_new_with_attributes(_("Freq"), renderer,
+    column = gtk_tree_view_column_new_with_attributes(_("Okuri"), renderer,
 						      "text", WORDLIST_OKURI,
 						      "editable", WORDLIST_EDITABLE,
 						      NULL);
-    gtk_tree_view_column_set_visible(column, FALSE);
     gtk_tree_view_append_column(view->view, column);
+    gtk_tree_view_column_set_visible(column, FALSE);
     view->okuri_column = column;
 
     store = gtk_list_store_new(WORDLIST_N_COLUMNS,
-			       G_TYPE_STRING,	/* Yomi	    */
-			       G_TYPE_STRING,	/* Kanji    */
-			       G_TYPE_STRING,	/* Code	    */
-			       G_TYPE_STRING,	/* Hinshi   */
-			       G_TYPE_INT,	/* Freq	    */
-			       G_TYPE_BOOLEAN,  /* Okuri for SKK */
-			       G_TYPE_BOOLEAN); /* Editable */
+			       G_TYPE_INT,      /* Word Type     */
+			       G_TYPE_STRING,	/* Phon	         */
+			       G_TYPE_STRING,	/* Desc          */
+			       G_TYPE_STRING,	/* cclass code   */
+			       G_TYPE_INT,	/* Frequency     */
+			       G_TYPE_BOOLEAN,	/* Okuri for SKK */
+			       G_TYPE_BOOLEAN); /* Editable      */
     gtk_tree_view_set_model(view->view, GTK_TREE_MODEL(store));
 
     view->model = GTK_TREE_MODEL(store);
 
-    view->code_show = FALSE;
-    view->hinshi_show = TRUE;
+    view->cclass_code_show = FALSE;
     view->freq_show = FALSE;
+    view->okuri_show = FALSE;
     view->editable = FALSE;
     view->selection_mode = GTK_SELECTION_SINGLE;
 }
@@ -289,7 +290,7 @@ static void wordlist_view_finalize(GObject *object) {
 }
 
 static void wordlist_view_destroy(GtkObject *object) {
-    WordlistView *view = WORDLIST_VIEW(object);
+/*    WordlistView *view = WORDLIST_VIEW(object); */
     if(GTK_OBJECT_CLASS(parent_class)->destroy) {
 	GTK_OBJECT_CLASS(parent_class)->destroy(object);
     }
@@ -341,7 +342,7 @@ GtkWidget *wordlist_view_new(void) {
  *
  * This is a function for creating a wordlist_view widget and setting
  * its properties in one go. For example you might write:
- * <literal>wordlist_view_new ("editable", TRUE, "code_show", FALSE, NULL)
+ * <literal>wordlist_view_new ("editable", TRUE, "freq_show", FALSE, NULL)
  * </literal> to create a wordlist_view with setting editable and hide
  * code column.
  *
@@ -362,38 +363,21 @@ GtkWidget *wordlist_view_new_with_attributes(const gchar *first_property_name,
     return widget;
 }
 
-void wordlist_view_set_visible_code_column(WordlistView *view,
+void wordlist_view_set_visible_cclass_code_column(WordlistView *view,
 					   gboolean show)
 {
     g_return_if_fail(IS_WORDLIST_VIEW(view));
-    if(view->code_show != show) {
-	view->code_show = show;
-	gtk_tree_view_column_set_visible(view->code_column, show);
-	g_object_notify(G_OBJECT(view), "code_show");
+    if(view->cclass_code_show != show) {
+	view->cclass_code_show = show;
+	gtk_tree_view_column_set_visible(view->cclass_code_column, show);
+	g_object_notify(G_OBJECT(view), "cclass_code_show");
     }
 }
 
-gboolean wordlist_view_get_visible_code_column(WordlistView *view) {
+gboolean wordlist_view_get_visible_cclass_code_column(WordlistView *view) {
     g_return_val_if_fail(IS_WORDLIST_VIEW(view), FALSE);
 
-    return view->code_show;
-}
-
-void wordlist_view_set_visible_hinshi_column(WordlistView *view,
-					     gboolean show)
-{
-    g_return_if_fail(IS_WORDLIST_VIEW(view));
-    if(view->hinshi_show != show) {
-	view->hinshi_show = show;
-	gtk_tree_view_column_set_visible(view->hinshi_column, show);
-	g_object_notify(G_OBJECT(view), "hinshi_show");
-    }
-}
-
-gboolean wordlist_view_get_visible_hinshi_column(WordlistView *view) {
-    g_return_val_if_fail(IS_WORDLIST_VIEW(view), FALSE);
-
-    return view->hinshi_show;
+    return view->cclass_code_show;
 }
 
 void wordlist_view_set_visible_freq_column(WordlistView *view, gboolean show) {
@@ -411,6 +395,22 @@ gboolean wordlist_view_get_visible_freq_column(WordlistView *view) {
     return view->freq_show;
 }
 
+void wordlist_view_set_visible_okuri_column(WordlistView *view, gboolean show)
+{
+    g_return_if_fail(IS_WORDLIST_VIEW(view));
+    if(view->okuri_show != show) {
+	view->okuri_show = show;
+	gtk_tree_view_column_set_visible(view->okuri_column, show);
+	g_object_notify(G_OBJECT(view), "okuri_show");
+    }
+}
+
+gboolean wordlist_view_get_visible_okuri_column(WordlistView *view) {
+    g_return_val_if_fail(IS_WORDLIST_VIEW(view), FALSE);
+
+    return view->okuri_show;
+}
+
 void wordlist_view_set_editable(WordlistView *view,
 				gboolean editable)
 {
@@ -462,15 +462,16 @@ static void wordlist_view_set_property(GObject *object,
     WordlistView *view = WORDLIST_VIEW(object);
 
     switch(prop_id) {
-    case PROP_CODE_SHOW:
-	wordlist_view_set_visible_code_column(view, g_value_get_boolean(value));
-	break;
-    case PROP_HINSHI_SHOW:
-	wordlist_view_set_visible_hinshi_column(view, g_value_get_boolean(value));
+    case PROP_CCLASS_CODE_SHOW:
+	wordlist_view_set_visible_cclass_code_column(view,
+						     g_value_get_boolean(value));
 	break;
     case PROP_FREQ_SHOW:
 	wordlist_view_set_visible_freq_column(view, g_value_get_boolean(value));
 	break;
+    case PROP_OKURI_SHOW:
+	wordlist_view_set_visible_okuri_column(view, g_value_get_boolean(value));
+	break;
     case PROP_EDITABLE:
 	wordlist_view_set_editable(view, g_value_get_boolean(value));
 	break;
@@ -490,15 +491,15 @@ static void wordlist_view_get_property(GObject *object,
 {
     WordlistView *view = WORDLIST_VIEW(object);
     switch(prop_id) {
-    case PROP_CODE_SHOW:
-	g_value_set_boolean(value, view->code_show);
-	break;
-    case PROP_HINSHI_SHOW:
-	g_value_set_boolean(value, view->hinshi_show);
+    case PROP_CCLASS_CODE_SHOW:
+	g_value_set_boolean(value, view->cclass_code_show);
 	break;
     case PROP_FREQ_SHOW:
 	g_value_set_boolean(value, view->freq_show);
 	break;
+    case PROP_OKURI_SHOW:
+	g_value_set_boolean(value, view->okuri_show);
+	break;
     case PROP_EDITABLE:
 	g_value_set_boolean(value, view->editable);
 	break;
@@ -512,72 +513,63 @@ static void wordlist_view_get_property(GObject *object,
 }
 
 void wordlist_view_set_values(WordlistView *view,
-			      WordlistData *data)
+			      word *data)
 {
     GtkTreeIter iter;
     g_return_if_fail(IS_WORDLIST_VIEW(view));
     g_return_if_fail(data != NULL);
 
-    if(data->yomi == NULL)
-	data->yomi = g_strdup("");
-    if(data->kanji == NULL)
-	data->kanji = g_strdup("");
-    if(data->code == NULL)
-	data->code = g_strdup("");
-    if(data->hinshi == NULL)
-	data->hinshi = g_strdup("");
+    if(data->phon == NULL)
+	data->phon = g_strdup("");
+    if(data->desc == NULL)
+	data->desc = g_strdup("");
+    if(data->cclass_code == NULL)
+	data->cclass_code = g_strdup("");
 
     gtk_list_store_append(GTK_LIST_STORE(view->model), &iter);
     gtk_list_store_set(GTK_LIST_STORE(view->model), &iter,
-		       WORDLIST_YOMI, data->yomi,
-		       WORDLIST_KANJI, data->kanji,
-		       WORDLIST_CODE, data->code,
-		       WORDLIST_HINSHI, data->hinshi,
-		       WORDLIST_FREQ, data->freq,
-		       WORDLIST_OKURI, data->okuri,
-		       WORDLIST_EDITABLE, view->editable,
+		       WORDLIST_WORD_TYPE,   data->type,
+		       WORDLIST_PHON,        data->phon,
+		       WORDLIST_DESC,        data->desc,
+		       WORDLIST_CCLASS_CODE, data->cclass_code,
+		       WORDLIST_FREQ,        data->freq,
+		       WORDLIST_OKURI,       data->okuri,
+		       WORDLIST_EDITABLE,    view->editable,
 		       -1);
 }
 
 void wordlist_view_clear(WordlistView *view) {
     g_return_if_fail(IS_WORDLIST_VIEW(view));
     g_return_if_fail(view->model);
+
     gtk_list_store_clear(GTK_LIST_STORE(view->model));
 }
 
 GList *wordlist_view_get_all_data_list(WordlistView *view) {
     GtkTreeIter iter;
     GList *list = NULL;
+    word *data;
 
     g_return_val_if_fail(IS_WORDLIST_VIEW(view), NULL);
 
     if(gtk_tree_model_get_iter_first(GTK_TREE_MODEL(view->model), &iter)) {
 	do {
-	    WordlistData *data;
-	    gchar *yomi, *kanji, *code, *hinshi;
-	    gint freq;
-	    gboolean okuri;
+	    data = g_new0(word, 1);
+	    if(data != NULL) {
+		gtk_tree_model_get(view->model, &iter,
+				   WORDLIST_WORD_TYPE,   &data->type,
+				   WORDLIST_PHON,        &data->phon,
+				   WORDLIST_DESC,        &data->desc,
+				   WORDLIST_CCLASS_CODE, &data->cclass_code,
+				   WORDLIST_FREQ,        &data->freq,
+				   WORDLIST_OKURI,       &data->okuri,
+				   -1);
 
-	    gtk_tree_model_get(view->model, &iter,
-			       WORDLIST_YOMI, &yomi,
-			       WORDLIST_KANJI, &kanji,
-			       WORDLIST_CODE, &code,
-			       WORDLIST_HINSHI, &hinshi,
-			       WORDLIST_FREQ, &freq,
-			       WORDLIST_OKURI, &okuri,
-			       -1);
-
-	    data = g_new0(WordlistData, 1);
-	    if(data != NULL && yomi != NULL && kanji != NULL &&
-		code != NULL && hinshi != NULL) {
-		data->yomi = g_strdup(yomi);
-		data->kanji = g_strdup(kanji);
-		data->code = g_strdup(code);
-		data->hinshi = g_strdup(hinshi);
-		data->freq = freq;
-		data->okuri = okuri;
-
-		list = g_list_append(list, data);
+		if(data->phon != NULL && data->desc != NULL &&
+		   data->cclass_code != NULL)
+		{
+		    list = g_list_append(list, data);
+		}
 	    }
 	} while(gtk_tree_model_iter_next(GTK_TREE_MODEL(view->model), &iter));
     }
@@ -602,16 +594,16 @@ GList* wordlist_view_get_selected_data_list(WordlistView *view) {
 	GtkTreePath *path = gtk_tree_row_reference_get_path(pos->data);
 	if(path) {
 	    if(gtk_tree_model_get_iter(view->model, &iter, path)) {
-		WordlistData *data;
+		word *data;
 
-		data = g_new0(WordlistData, 1);
+		data = g_new0(word, 1);
 		gtk_tree_model_get(view->model, &iter,
-				   WORDLIST_YOMI, &data->yomi,
-				   WORDLIST_KANJI, &data->kanji,
-				   WORDLIST_CODE, &data->code,
-				   WORDLIST_HINSHI, &data->hinshi,
-				   WORDLIST_FREQ, &data->freq,
-				   WORDLIST_OKURI, &data->okuri,
+				   WORDLIST_WORD_TYPE,   &data->type,
+				   WORDLIST_PHON,        &data->phon,
+				   WORDLIST_DESC,        &data->desc,
+				   WORDLIST_CCLASS_CODE, &data->cclass_code,
+				   WORDLIST_FREQ,        &data->freq,
+				   WORDLIST_OKURI,       &data->okuri,
 				   -1);
 
 		selected_data = g_list_append(selected_data, data);
@@ -669,10 +661,9 @@ static void wordlist_view_callback_cell_edited(GtkCellRendererText *renderer,
     gtk_tree_model_get_iter(model, &iter, path);
 
     switch(GPOINTER_TO_INT(column)) {
-    case WORDLIST_YOMI:
-    case WORDLIST_KANJI:
-    case WORDLIST_CODE:
-    case WORDLIST_HINSHI:
+    case WORDLIST_PHON:
+    case WORDLIST_DESC:
+    case WORDLIST_CCLASS_CODE:
 	gtk_tree_model_get(model, &iter,
 			   column, &old_text,
 			   -1);
